@@ -1,27 +1,29 @@
-# Copyright (C) 2008 Andi Albrecht, albrecht.andi@gmail.com
+#
+# Copyright (C) 2009-2020 the sqlparse authors and contributors
+# <see AUTHORS file>
 #
 # This module is part of python-sqlparse and is released under
-# the BSD License: http://www.opensource.org/licenses/bsd-license.php.
+# the BSD License: https://opensource.org/licenses/BSD-3-Clause
 
 """Parse SQL statements."""
 
-
-__version__ = '0.1.18'
-
-
 # Setup namespace
+from sqlparse import sql
+from sqlparse import cli
 from sqlparse import engine
+from sqlparse import tokens
 from sqlparse import filters
 from sqlparse import formatter
 
-# Deprecated in 0.1.5. Will be removed in 0.2.0
-from sqlparse.exceptions import SQLParseError
+
+__version__ = '0.4.0'
+__all__ = ['engine', 'filters', 'formatter', 'sql', 'tokens', 'cli']
 
 
 def parse(sql, encoding=None):
     """Parse sql and return a list of statements.
 
-    :param sql: A string containting one or more SQL statements.
+    :param sql: A string containing one or more SQL statements.
     :param encoding: The encoding of the statement (optional).
     :returns: A tuple of :class:`~sqlparse.sql.Statement` instances.
     """
@@ -36,11 +38,11 @@ def parsestream(stream, encoding=None):
     :returns: A generator of :class:`~sqlparse.sql.Statement` instances.
     """
     stack = engine.FilterStack()
-    stack.full_analyze()
+    stack.enable_grouping()
     return stack.run(stream, encoding)
 
 
-def format(sql, **options):
+def format(sql, encoding=None, **options):
     """Format *sql* according to *options*.
 
     Available options are documented in :ref:`formatting`.
@@ -50,7 +52,6 @@ def format(sql, **options):
 
     :returns: The formatted SQL statement as string.
     """
-    encoding = options.pop('encoding', None)
     stack = engine.FilterStack()
     options = formatter.validate_options(options)
     stack = formatter.build_filter_stack(stack, options)
@@ -61,18 +62,9 @@ def format(sql, **options):
 def split(sql, encoding=None):
     """Split *sql* into single statements.
 
-    :param sql: A string containting one or more SQL statements.
+    :param sql: A string containing one or more SQL statements.
     :param encoding: The encoding of the statement (optional).
     :returns: A list of strings.
     """
     stack = engine.FilterStack()
-    stack.split_statements = True
-    return [unicode(stmt).strip() for stmt in stack.run(sql, encoding)]
-
-
-from sqlparse.engine.filter import StatementFilter
-
-
-def split2(stream):
-    splitter = StatementFilter()
-    return list(splitter.process(None, stream))
+    return [str(stmt).strip() for stmt in stack.run(sql, encoding)]
